@@ -371,7 +371,9 @@ sf_flac_meta_get_vorbiscomments (SF_PRIVATE *psf, const FLAC__StreamMetadata *me
 		{ "comment", SF_STR_COMMENT },
 		{ "date", SF_STR_DATE },
 		{ "album", SF_STR_ALBUM },
-		{ "license", SF_STR_LICENSE }
+		{ "license", SF_STR_LICENSE },
+		{ "tracknumber", SF_STR_TRACKNUMBER },
+		{ "genre", SF_STR_GENRE }
 		} ;
 
 	const char *value, *cptr ;
@@ -572,6 +574,12 @@ flac_write_strings (SF_PRIVATE *psf, FLAC_PRIVATE* pflac)
 			case SF_STR_LICENSE :
 				key = "license" ;
 				break ;
+			case SF_STR_TRACKNUMBER :
+				key = "tracknumber" ;
+				break ;
+			case SF_STR_GENRE :
+				key = "genre" ;
+				break ;
 			default :
 				continue ;
 			} ;
