@@ -104,6 +104,8 @@ static STR_PAIRS vorbis_metatypes [] =
 	{	SF_STR_DATE,		"Date" },
 	{	SF_STR_ALBUM,		"Album" },
 	{	SF_STR_LICENSE,		"License" },
+	{	SF_STR_TRACKNUMBER,	"Tracknumber" },
+	{	SF_STR_GENRE,		"Genre" },
 } ;
 
 typedef struct
@@ -378,14 +380,16 @@ ogg_write_header (SF_PRIVATE *psf, int UNUSED (calc_length))
 			break ;
 
 		switch (psf->strings [k].type)
-		{	case SF_STR_TITLE :		name = "TITLE" ; break ;
-			case SF_STR_COPYRIGHT : name = "COPYRIGHT" ; break ;
-			case SF_STR_SOFTWARE :	name = "SOFTWARE" ; break ;
-			case SF_STR_ARTIST :	name = "ARTIST" ; break ;
-			case SF_STR_COMMENT :	name = "COMMENT" ; break ;
-			case SF_STR_DATE :		name = "DATE" ; break ;
-			case SF_STR_ALBUM :		name = "ALBUM" ; break ;
-			case SF_STR_LICENSE :	name = "LICENSE" ; break ;
+		{	case SF_STR_TITLE :			name = "TITLE" ; break ;
+			case SF_STR_COPYRIGHT : 	name = "COPYRIGHT" ; break ;
+			case SF_STR_SOFTWARE :		name = "SOFTWARE" ; break ;
+			case SF_STR_ARTIST :		name = "ARTIST" ; break ;
+			case SF_STR_COMMENT :		name = "COMMENT" ; break ;
+			case SF_STR_DATE :			name = "DATE" ; break ;
+			case SF_STR_ALBUM :			name = "ALBUM" ; break ;
+			case SF_STR_LICENSE :		name = "LICENSE" ; break ;
+			case SF_STR_TRACKNUMBER :	name = "TRACKNUMBER" ; break ;
+			case SF_STR_GENRE :			name = "GENRE" ; break ;
 			default : continue ;
 			} ;
 
