@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2008-2009 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 2008-2010 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU Lesser General Public License as published by
@@ -40,6 +40,9 @@ main (void)
 	test_audio_detect () ;
 	test_ima_oki_adpcm () ;
 
+	test_strncpy_crlf () ;
+	test_broadcast_var () ;
+
 	return 0 ;
 } /* main */
 
