@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1999-2005 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 1999-2009 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@ main (void)
 	vio_test ("vio_pcm16.wav", SF_FORMAT_WAV | SF_FORMAT_PCM_16) ;
 	vio_test ("vio_pcm24.aiff", SF_FORMAT_AIFF | SF_FORMAT_PCM_24) ;
 	vio_test ("vio_float.au", SF_FORMAT_AU | SF_FORMAT_FLOAT) ;
+	vio_test ("vio_pcm24.paf", SF_FORMAT_PAF | SF_FORMAT_PCM_24) ;
 
 	return 0 ;
 } /* main */
@@ -106,10 +107,10 @@ vfwrite (const void *ptr, sf_count_t count, void *user_data)
 	**	This will break badly for files over 2Gig in length, but
 	**	is sufficient for testing.
 	*/
-	if (vf->offset >= sizeof (vf->data))
+	if (vf->offset >= SIGNED_SIZEOF (vf->data))
 		return 0 ;
 
-	if (vf->offset + count > sizeof (vf->data))
+	if (vf->offset + count > SIGNED_SIZEOF (vf->data))
 		count = sizeof (vf->data) - vf->offset ;
 
 	memcpy (vf->data + vf->offset, ptr, (size_t) count) ;
@@ -189,6 +190,11 @@ vio_test (const char *fname, int format)
 		exit (1) ;
 		} ;
 
+	if (vfget_filelen (&vio_data) < 0)
+	{	printf ("\n\nLine %d : vfget_filelen returned negative length.\n\n", __LINE__) ;
+		exit (1) ;
+		} ;
+
 	gen_short_data (data, ARRAY_LEN (data), 0) ;
 	sf_write_short (file, data, ARRAY_LEN (data)) ;
 
@@ -229,10 +235,3 @@ vio_test (const char *fname, int format)
 	puts ("ok") ;
 } /* vio_test */
 
-/*
-** Do not edit or modify anything in this comment block.
-** The arch-tag line is a file identity tag for the GNU Arch 
-** revision control system.
-**
-** arch-tag: 5569fa52-15dd-496f-ab47-1fd42d76195d
-*/
